#!/usr/local/bin/tclsh

set FDATE ""
set TDATE ""
set FTIME ""
set TTIME ""
set NOEXIT "false"
set DEBUG "false"

#
# echoerr is used to echo messages to stderr
#
proc echoerr str {
  global NOEXIT
  puts stderr "$str"
  if {"$NOEXIT" != "true"} {
    exit 1
  }
}

#
# echoout is used to echo messages to stdout
#
proc echoout str {
  puts stdout "$str"
}

#
# fatalerr is used to echo messages to stderr and exit
#
proc fatalerr str {
  puts stderr "$str"
  exit 1
}

#
# echodbg is used to echo debug messages to stderr. Messages are echo'ed if
# the global variable DEBUG is set to "true".
#
proc echodbg args {
  global DEBUG
  if { "$DEBUG" == "true" } {
    puts stderr "$args"
  }
}

#
# execit is used to execute commands and capture their output. The output is
# returned in the 'output' argument and the procedure returns with the exit code
# of the command.
#
proc execit {output args} {
  upvar $output result
  set exitval [catch {eval exec $args} result]
  return $exitval
}

#
# execute_command is used to execute a command and capture errors.
#   opt - -1:no display, 0:display all output,
#          1:display on success only, 2:display on error only
#
proc execute_command {opt args} {
  global execute_command_err

  echodbg $opt $args
  set exitval [catch {eval exec $args} result]
  if {$exitval != 0} {
    if {"$result" != ""} {
      switch $opt {
        0 -
        2 {puts stderr "$result"}
      }
    }
    set execute_command_err "true"
    echoerr "Customize failed executing: $args.\nPlease correct the problem and rerun customize."
  } else {
    if {"$result" != ""} {
      switch $opt {
        0 -
        1 {puts stdout "$result"}
      }
    }
  }
}

#
# Start of main script
#

if {[info exists env(NOARGS)] == 0} {
  set env(NOARGS) ""
}
if {[info exists env(A1)] == 0} {
  set env(A1) ""
}
if {[info exists env(A2)] == 0} {
  set env(A2) ""
}
if {[info exists env(A3)] == 0} {
  set env(A3) ""
}
if {[info exists env(A4)] == 0} {
  set env(A4) ""
}
if {[info exists env(A5)] == 0} {
  set env(A5) ""
}
if {[info exists env(A6)] == 0} {
  set env(A6) ""
}
if {[info exists env(A7)] == 0} {
  set env(A7) ""
}

if {"$env(NOARGS)" != ""} {
  execit FDATE datecalc today - 1 days PIC yyyymmdd
  execit TDATE datecalc today PIC yyyymmdd
  execit FTIME datecalc today PIC HHTT
  set TTIME $FTIME
  execute_command 0 syxtract -F$FDATE -T$TDATE -B$FTIME -E$TTIME | gsort +0 -1 +1 -2 +2 -3 | report8 -F$FDATE -T$TDATE -B$FTIME -E$TTIME
} else {
  if {"$env(A1)" == ""} {
    execit FDATE datecalc today PIC yyyymmdd
    set env(A1) "-F$FDATE"
    set TDATE $FDATE
    set env(A2) "-T$TDATE"
  }
  execute_command 0 syxtract $env(A1) $env(A2) $env(A3) $env(A4) $env(A7) | gsort +0 -1 +1 -2 +2 -3 | report8 $env(A1) $env(A2) $env(A3) $env(A4) $env(A5)
}

exit
